==> engine-xml-2017.7.4-sources.jar: com/xebialabs/xltype/serialization/xstream/DeploymentConverter.java <==
/**
 * Copyright 2014-2018 XebiaLabs Inc. and its affiliates. Use is subject to terms of the enclosed Legal Notice.
 */
package com.xebialabs.xltype.serialization.xstream;

import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.xebialabs.deployit.engine.api.dto.ConfigurationItemId;
import com.xebialabs.deployit.engine.api.dto.Deployment;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;

import java.util.List;

import static com.xebialabs.xltype.serialization.xstream.Converters.readList;
import static com.xebialabs.xltype.serialization.xstream.Converters.writeConfigurationItem;


@XStreamProvider(tagName = "deployment", readable = Deployment.class)
public class DeploymentConverter implements Converter {
    @Override
    public void marshal(Object source, HierarchicalStreamWriter writer, MarshallingContext context) {
        Deployment depl = (Deployment) source;
        if (depl.getId() != null) {
            writer.addAttribute("id", depl.getId());
        }
        writer.addAttribute("type", depl.getDeploymentType().name());

        writer.startNode("deploymentGroupIndex");
        writer.setValue(String.valueOf(depl.getDeploymentGroupIndex()));
        writer.endNode();

        writer.startNode("application");
        writeConfigurationItem(depl.getDeployedApplication(), writer, context);
        writer.endNode();
        writer.startNode("deployeds");
        for (ConfigurationItem configurationItem : depl.getDeployeds()) {
            writeConfigurationItem(configurationItem, writer, context);
        }
        writer.endNode();
        writeIds("deployables", depl.getDeployables(), writer, context);
        writeIds("containers", depl.getContainers(), writer, context);

        writer.startNode("requiredDeployments");
        for (Deployment d : depl.getRequiredDeployments()) {
            writer.startNode("deployment");
            context.convertAnother(d);
            writer.endNode();
        }

        writer.endNode();
    }

    private void writeIds(String nodeName, List<ConfigurationItemId> ids, HierarchicalStreamWriter writer, MarshallingContext context) {
        writer.startNode(nodeName);
        for (ConfigurationItemId configurationItemId : ids) {
            writerConfigurationItemId(configurationItemId, writer, context);
        }
        writer.endNode();
    }

    private void writerConfigurationItemId(ConfigurationItemId configurationItemId, HierarchicalStreamWriter writer, MarshallingContext context) {
        writer.startNode("ci");
        context.convertAnother(configurationItemId);
        writer.endNode();
    }

    @Override
    public Object unmarshal(HierarchicalStreamReader reader, UnmarshallingContext context) {
        Deployment depl = new Deployment();
        depl.setId(reader.getAttribute("id"));
        depl.setDeploymentType(Deployment.DeploymentType.valueOf(reader.getAttribute("type")));
        while (reader.hasMoreChildren()) {
            reader.moveDown();
            if ("application".equals(reader.getNodeName())) {
                reader.moveDown();
                ConfigurationItem ci = (ConfigurationItem) context.convertAnother(depl, ConfigurationItem.class);
                depl.setDeployedApplication(ci);
                reader.moveUp();
            } else if ("deployeds".equals(reader.getNodeName())) {
                depl.setDeployeds(readList(depl, ConfigurationItem.class, reader, context));
            } else if ("deployables".equals(reader.getNodeName())) {
                depl.setDeployables(readList(depl, ConfigurationItemId.class, reader, context));
            } else if ("containers".equals(reader.getNodeName())) {
                depl.setContainers(readList(depl, ConfigurationItemId.class, reader, context));
            } else if ("requiredDeployments".equals(reader.getNodeName())) {
                depl.setRequiredDeployments(readList(depl, Deployment.class, reader, context));
            } else if ("deploymentGroupIndex".equals(reader.getNodeName())) {
                String value = reader.getValue();
                if (!value.isEmpty()) {
                    depl.setDeploymentGroupIndex(Integer.valueOf(value));
                }
            }
            reader.moveUp();
        }
        return depl;
    }

    @Override
    public boolean canConvert(Class type) {
        return Deployment.class.isAssignableFrom(type);
    }
}

==> engine-xml-2019.1.2-sources.jar: com/xebialabs/xltype/serialization/xstream/DeploymentConverter.java <==
/**
 * Copyright 2014-2018 XebiaLabs Inc. and its affiliates. Use is subject to terms of the enclosed Legal Notice.
 */
package com.xebialabs.xltype.serialization.xstream;

import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;
import com.xebialabs.deployit.engine.api.dto.ConfigurationItemId;
import com.xebialabs.deployit.engine.api.dto.Deployment;
import com.xebialabs.deployit.plugin.api.deployment.ResolvedPlaceholder;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;

import java.util.List;

import static com.xebialabs.xltype.serialization.xstream.Converters.readList;
import static com.xebialabs.xltype.serialization.xstream.Converters.readPlaceholders;
import static com.xebialabs.xltype.serialization.xstream.Converters.writeConfigurationItem;


@XStreamProvider(tagName = "deployment", readable = Deployment.class)
public class DeploymentConverter implements Converter {

    @Override
    public void marshal(Object source, HierarchicalStreamWriter writer, MarshallingContext context) {
        Deployment depl = (Deployment) source;
        if (depl.getId() != null) {
            writer.addAttribute("id", depl.getId());
        }
        writer.addAttribute("type", depl.getDeploymentType().name());

        writer.startNode("deploymentGroupIndex");
        writer.setValue(String.valueOf(depl.getDeploymentGroupIndex()));
        writer.endNode();

        writer.startNode("application");
        writeConfigurationItem(depl.getDeployedApplication(), writer, context);
        writer.endNode();
        writer.startNode("deployeds");
        for (ConfigurationItem configurationItem : depl.getDeployeds()) {
            writeConfigurationItem(configurationItem, writer, context);
        }
        writer.endNode();
        writeIds("deployables", depl.getDeployables(), writer, context);
        writeIds("containers", depl.getContainers(), writer, context);

        writer.startNode("resolvedPlaceholders");
        for (ResolvedPlaceholder placeholder : depl.getResolvedPlaceholders()) {
            writer.startNode("placeholder");
            writer.addAttribute("encrypted", String.valueOf(placeholder.isEncrypted()));
            writer.addAttribute("containerId", placeholder.containerId());
            writer.addAttribute("deployedAppId", placeholder.deployedAppId());
            writer.addAttribute("dictionaryId", placeholder.dictionaryId());
            writer.addAttribute("environmentId", placeholder.environmentId());
            writer.addAttribute("versionId", placeholder.versionId());
            writer.addAttribute("key", placeholder.key());
            writer.addAttribute("value", placeholder.value());
            writer.endNode();
        }
        writer.endNode();

        writer.startNode("requiredDeployments");
        for (Deployment d : depl.getRequiredDeployments()) {
            writer.startNode("deployment");
            context.convertAnother(d);
            writer.endNode();
        }

        writer.endNode();
    }

    private void writeIds(String nodeName, List<ConfigurationItemId> ids, HierarchicalStreamWriter writer, MarshallingContext context) {
        writer.startNode(nodeName);
        for (ConfigurationItemId configurationItemId : ids) {
            writerConfigurationItemId(configurationItemId, writer, context);
        }
        writer.endNode();
    }

    private void writerConfigurationItemId(ConfigurationItemId configurationItemId, HierarchicalStreamWriter writer, MarshallingContext context) {
        writer.startNode("ci");
        context.convertAnother(configurationItemId);
        writer.endNode();
    }

    @Override
    public Object unmarshal(HierarchicalStreamReader reader, UnmarshallingContext context) {
        Deployment depl = new Deployment();
        depl.setId(reader.getAttribute("id"));
        depl.setDeploymentType(Deployment.DeploymentType.valueOf(reader.getAttribute("type")));
        while (reader.hasMoreChildren()) {
            reader.moveDown();
            if ("application".equals(reader.getNodeName())) {
                reader.moveDown();
                ConfigurationItem ci = (ConfigurationItem) context.convertAnother(depl, ConfigurationItem.class);
                depl.setDeployedApplication(ci);
                reader.moveUp();
            } else if ("deployeds".equals(reader.getNodeName())) {
                depl.setDeployeds(readList(depl, ConfigurationItem.class, reader, context));
            } else if ("deployables".equals(reader.getNodeName())) {
                depl.setDeployables(readList(depl, ConfigurationItemId.class, reader, context));
            } else if ("containers".equals(reader.getNodeName())) {
                depl.setContainers(readList(depl, ConfigurationItemId.class, reader, context));
            } else if ("requiredDeployments".equals(reader.getNodeName())) {
                depl.setRequiredDeployments(readList(depl, Deployment.class, reader, context));
            } else if ("deploymentGroupIndex".equals(reader.getNodeName())) {
                String value = reader.getValue();
                if (!value.isEmpty()) {
                    depl.setDeploymentGroupIndex(Integer.valueOf(value));
                }
            } else if ("resolvedPlaceholders".equals(reader.getNodeName())) {
                depl.addResolvedPlaceholders(readPlaceholders(reader));
            }
            reader.moveUp();
        }
        return depl;
    }

    @Override
    public boolean canConvert(Class type) {
        return Deployment.class.isAssignableFrom(type);
    }
}
